Welcome to Ril's documentation!
====================================

Rust Imaging Library's Python binding: A performant and high-level image processing library for Python written in Rust 

Ril
===

Contents
========

.. toctree::
    :maxdepth: 2

    API Reference <ril.rst>

Index
=====
* :ref:`genindex`
